from pathlib import Path
from hmd_lib_containers.config.build_config import ImageBuildConfig, ImageBuildSecret
from hmd_cli_tools.hmd_cli_tools import read_manifest


def get_default_pip_secret(pip_conf_name: str):
    return ImageBuildSecret(id="pipconfig", src=pip_conf_name)


class HmdDockerDefaultBuildConfig(ImageBuildConfig):
    context_dir = Path(
        "./src/docker"
    )  # Remove this when all Dockerfiles have been updated

    @staticmethod
    def from_manifest():
        try:
            manifest = read_manifest()
        except Exception as e:
            manifest = {}

        docker_cfg = manifest.get("docker", {}).get(
            "build", {"context_dir": "./src/docker"}
        )

        # Convert secret dicts to ImageBuildSecret class
        if "secrets" in docker_cfg:
            docker_cfg["secrets"] = [
                ImageBuildSecret(id=secret["id"], src=secret["src"])
                for secret in docker_cfg["secrets"]
            ]

        return HmdDockerDefaultBuildConfig(**docker_cfg)
